Macro fif::writablesln [−][src]
macro_rules! writablesln {
[$($args : tt), +] => { ... };
}Expand description
Does the same thing as writables, but adds a Newline to the end.
macro_rules! writablesln {
[$($args : tt), +] => { ... };
}Does the same thing as writables, but adds a Newline to the end.